componenttools.yield_groups_of_mixed_klasses_in_sequence
========================================================

.. autofunction:: abjad.tools.componenttools.yield_groups_of_mixed_klasses_in_sequence.yield_groups_of_mixed_klasses_in_sequence
